IosCommand class

Inheritance

Constructors

IosCommand()

Properties

aliases → List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
category → String
The command's category.
no setterinherited
description → String
A description of this command, included in usage.
no setteroverride
dingdingHookUrl → String
no setteroverride
environment ↔ Environment
当前打包运行环境的参数
getter/setter pairinherited
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether or not this command should be hidden from help listings.
no setterinherited
hookUrl → String
no setteroverride
invocation → String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
isStoreVersion → bool
no setterinherited
log → String
no setterinherited
logFooter → String
日志尾
no setteroverride
logHeader → String
日志头
no setteroverride
name → String
The name of this command.
no setteroverride
parent → Command?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner?
The command runner for this command.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setupFastlane → SetupFastlane
no setteroverride
subcommands → Map<String, Command>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases → List<String>
Alternate non-functional names for this command.
no setterinherited
summary → String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments → bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
unityFrameworkPath → String
需要复制到对应工程Unity路径
no setteroverride
unityFullPath → String?
Unity工程的全路径 如果iOS则是iOSUnity的路径 如果Android则是AndroidUnity的路径
no setteroverride
usage → String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter → String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command command) → void
Adds Command as a subcommand of this.
inherited
build(String root) → Future
override
getBuildConfigManager({required AppwriteEnvironment appwriteEnvironment}) → BuildConfigManager
override
getBuildInfo(BuildConfig buildConfig) → BuildInfo
override
init() → dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
run() → FutureOr?
Runs this command.
inherited
sendWeChat(String log) → dynamic
inherited
toString() → String
A string representation of this object.
inherited
updateGitBranch(String root) → Future<bool>
inherited
updateUnity(UnityEnvironment unityEnvironment) → Future
override
upload(String root) → Future
override
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited