BuildConfigManager class

Constructors

BuildConfigManager({required AppwriteEnvironment environment, required String platform, required String branch})
const

Properties

branch → String
final
environment → AppwriteEnvironment
final
hashCode → int
The hash code for this object.
no setterinherited
platform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBuildConfig() → Future<BuildInfo?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBuildConfig({required BuildInfo? buildInfo, required String buildName, required int buildTime}) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited