FixIosUnityCache class

Constructors

FixIosUnityCache({required String root, required String iosUnityPath})

Properties

hashCode → int
The hash code for this object.
no setterinherited
iosBuidDir → String
no setter
iosUnityPath → String
final
projectPath → String
no setter
root → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toLibil2cppPath → String
no setter

Methods

containsBitCode(String content) → bool
fix() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited