SetupFastlane class abstract

Implementers

Constructors

SetupFastlane({required String root})

Properties

fastlaneContent → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
root → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fastlaneFile(String root) → File
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup() → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited